@@ -427,16 +427,16 @@ static uptr uf_uptrin(unbufFaslFile uf, INT *bytes_consumed) {
 }
 
 char *S_format_scheme_version(uptr n) {
-  static char buf[20]; INT len;
+  static char buf[40]; INT len;
   if ((n >> 24) != ((n >> 24) & 0xffff)) return "unknown";
   if ((n & 0xff) == 0) {
     if ((n & 0xff) == 0)
-      len = snprintf(buf, 20, "%d.%d", (int) n >> 24, (int) (n >> 16) & 0xff);
+      len = snprintf(buf, sizeof(buf), "%d.%d", (int) n >> 24, (int) (n >> 16) & 0xff);
     else
-      len = snprintf(buf, 20, "%d.%d.%d", (int) n >> 24, (int) (n >> 16) & 0xff, 
+      len = snprintf(buf, sizeof(buf), "%d.%d.%d", (int) n >> 24, (int) (n >> 16) & 0xff,
                      (int) (n >> 8) & 0xff);
   } else
-    len = snprintf(buf, 20, "%d.%d.%d.%d", (int) n >> 24, (int) (n >> 16) & 0xff, 
+    len = snprintf(buf, sizeof(buf), "%d.%d.%d-pre-release.%d", (int) n >> 24, (int) (n >> 16) & 0xff,
                    (int) (n >> 8) & 0xff, (int) n & 0xff);
   return len > 0 ? buf : "unknown";
 }
@@ -1125,9 +1125,10 @@ static void faslin(ptr tc, ptr *x, ptr t, ptr *pstrbuf, faslFile f) {
             *x = S_phantom_bytevector(uptrin(f));
             return;
         case fasl_type_graph: {
-            uptr len = uptrin(f), len2, i;
+            uptr len = uptrin(f), len2 = uptrin(f), tlen = (uptr)Svector_length(t), i;
             ptr new_t = S_vector(len);
-            len2 = Svector_length(t);
+            if ((tlen < len2) && (len2 != 0)) /* allowing a vector when not needed helps with `load-compiled-from-port` */
+              S_error2("", "incompatible external vector length ~d, expected ~d", FIX(tlen), FIX(len2));
             if (len2 > len) len2 = len;
             for (i = 0; i < len2; i++)
               INITVECTIT(new_t, i+(len-len2)) = Svector_ref(t, i);
@@ -1877,8 +1878,7 @@ static uptr sparc64_get_literal(void *address) {
   return item;
 }
 
-static U32 adjust_delay_inst(delay_inst, old_call_addr, new_call_addr)
-      U32 delay_inst; U32 *old_call_addr, *new_call_addr; {
+static U32 adjust_delay_inst(U32 delay_inst, U32 *old_call_addr, U32 *new_call_addr) {
   INT offset;
 
   offset = sizeof(U32) * (old_call_addr - new_call_addr);
