@@ -18,7 +18,7 @@ static void pre_filter_cmdline_arguments(int *argc, char ***argv);
 char *check_for_another = "yes, please check for another";
 
 # include <windows.h>
-# include "../start/win_single.inc"
+# include "../../start/win_single.inc"
 # define CHECK_SINGLE_INSTANCE
 #endif
 
