@@ -28,6 +28,7 @@
 #define XFORM_SKIP_PROC /* empty */
 
 #include "../../start/config.inc"
+#include "path_replace.inc"
 
 #ifdef WIN32
 typedef void *(*scheme_dll_open_proc)(const char *name, int as_global);
@@ -92,7 +93,7 @@ static const char *get_framework_path() {
   return NULL;
 }
 
-static char *path_append(const char *p1, char *p2) {
+static char *path_append(const char *p1, const char *p2) {
   int l1, l2;
   char *s;
   l1 = strlen(p1);
@@ -129,21 +130,6 @@ static void *extract_dlldir()
 }
 #endif
 
-static char *path_replace(const char *s, const char *new_file)
-{
-  int len1 = strlen(s), len2 = strlen(new_file);
-  char *r;
-
-  while ((len1 > 0) && (s[len1-1] != '/') && (s[len1-1] != '\\'))
-    len1--;
-
-  r = malloc(len1+len2+1);
-  memcpy(r, (void *)s, len1);
-  memcpy(r+len1, (void *)new_file, len2+1);
-
-  return r;
-}
-
 #ifndef do_pre_filter_cmdline_arguments
 # define do_pre_filter_cmdline_arguments(argc, argv) /* empty */
 #endif
@@ -240,12 +226,12 @@ static int bytes_main(int argc, char **argv,
       && (boot3_offset == 0)
       && (boot1_path == boot2_path)
       && (boot1_path == boot3_path)) {
-    /* No offsets have been set, so we must be trying to run
+    /* No offsets have been set, so we must be trying< to run
        something like `raw_racketcs` during the build process.
        Look for boot files adjacent to the executable. */
-    boot1_path = path_replace(boot_exe, "petite-v.boot");
-    boot2_path = path_replace(boot_exe, "scheme-v.boot");
-    boot3_path = path_replace(boot_exe, "racket-v.boot");
+    boot1_path = path_replace_filename(boot_exe, "petite-v.boot");
+    boot2_path = path_replace_filename(boot_exe, "scheme-v.boot");
+    boot3_path = path_replace_filename(boot_exe, "racket-v.boot");
   }
 
   {
