@@ -159,14 +159,13 @@
    #f
    'known-constant))
 (define struct:known-constant
-  (make-record-type-descriptor*
+  (make-record-type-descriptor
    'known-constant
    #f
    (structure-type-lookup-prefab-uid 'known-constant #f 0 0 #f '())
    #f
    #f
-   0
-   0))
+   '(0 . 0)))
 (define effect_2537 (finish_2045 struct:known-constant))
 (define known-constant
   (|#%name|
@@ -200,7 +199,7 @@
    #f
    'known-consistent))
 (define struct:known-consistent
-  (make-record-type-descriptor*
+  (make-record-type-descriptor
    'known-consistent
    (if (struct-type? struct:known-constant)
      struct:known-constant
@@ -216,8 +215,7 @@
     '())
    #f
    #f
-   0
-   0))
+   '(0 . 0)))
 (define effect_2382 (finish_2081 struct:known-consistent))
 (define known-consistent
   (|#%name|
@@ -251,7 +249,7 @@
    #f
    'known-authentic))
 (define struct:known-authentic
-  (make-record-type-descriptor*
+  (make-record-type-descriptor
    'known-authentic
    (if (struct-type? struct:known-constant)
      struct:known-constant
@@ -267,8 +265,7 @@
     '())
    #f
    #f
-   0
-   0))
+   '(0 . 0)))
 (define effect_2570 (finish_2443 struct:known-authentic))
 (define known-authentic
   (|#%name|
@@ -302,7 +299,7 @@
    #f
    'known-copy))
 (define struct:known-copy
-  (make-record-type-descriptor*
+  (make-record-type-descriptor
    'known-copy
    (if (struct-type? struct:known-constant)
      struct:known-constant
@@ -318,8 +315,7 @@
     '(0))
    #f
    #f
-   1
-   1))
+   '(1 . 1)))
 (define effect_2542 (finish_2536 struct:known-copy))
 (define known-copy
   (|#%name|
@@ -361,7 +357,7 @@
    #f
    'known-literal))
 (define struct:known-literal
-  (make-record-type-descriptor*
+  (make-record-type-descriptor
    'known-literal
    (if (struct-type? struct:known-consistent)
      struct:known-consistent
@@ -377,8 +373,7 @@
     '(0))
    #f
    #f
-   1
-   1))
+   '(1 . 1)))
 (define effect_2788 (finish_2861 struct:known-literal))
 (define known-literal
   (|#%name|
@@ -427,7 +422,7 @@
    #f
    'known-procedure))
 (define struct:known-procedure
-  (make-record-type-descriptor*
+  (make-record-type-descriptor
    'known-procedure
    (if (struct-type? struct:known-consistent)
      struct:known-consistent
@@ -443,8 +438,7 @@
     '(0))
    #f
    #f
-   1
-   1))
+   '(1 . 1)))
 (define effect_2677 (finish_2897 struct:known-procedure))
 (define known-procedure
   (|#%name|
@@ -495,7 +489,7 @@
    #f
    'known-procedure/single-valued))
 (define struct:known-procedure/single-valued
-  (make-record-type-descriptor*
+  (make-record-type-descriptor
    'known-procedure/single-valued
    (if (struct-type? struct:known-procedure)
      struct:known-procedure
@@ -511,8 +505,7 @@
     '())
    #f
    #f
-   0
-   0))
+   '(0 . 0)))
 (define effect_2532 (finish_2542 struct:known-procedure/single-valued))
 (define known-procedure/single-valued
   (|#%name|
@@ -551,7 +544,7 @@
    #f
    'known-procedure/no-prompt))
 (define struct:known-procedure/no-prompt
-  (make-record-type-descriptor*
+  (make-record-type-descriptor
    'known-procedure/no-prompt
    (if (struct-type? struct:known-procedure/single-valued)
      struct:known-procedure/single-valued
@@ -567,8 +560,7 @@
     '())
    #f
    #f
-   0
-   0))
+   '(0 . 0)))
 (define effect_1771 (finish_2099 struct:known-procedure/no-prompt))
 (define known-procedure/no-prompt
   (|#%name|
@@ -607,7 +599,7 @@
    #f
    'known-procedure/no-prompt/multi))
 (define struct:known-procedure/no-prompt/multi
-  (make-record-type-descriptor*
+  (make-record-type-descriptor
    'known-procedure/no-prompt/multi
    (if (struct-type? struct:known-procedure)
      struct:known-procedure
@@ -623,8 +615,7 @@
     '())
    #f
    #f
-   0
-   0))
+   '(0 . 0)))
 (define effect_2793 (finish_2719 struct:known-procedure/no-prompt/multi))
 (define known-procedure/no-prompt/multi
   (|#%name|
@@ -663,7 +654,7 @@
    #f
    'known-procedure/no-return))
 (define struct:known-procedure/no-return
-  (make-record-type-descriptor*
+  (make-record-type-descriptor
    'known-procedure/no-return
    (if (struct-type? struct:known-procedure/single-valued)
      struct:known-procedure/single-valued
@@ -679,8 +670,7 @@
     '())
    #f
    #f
-   0
-   0))
+   '(0 . 0)))
 (define effect_2517 (finish_2574 struct:known-procedure/no-return))
 (define known-procedure/no-return
   (|#%name|
@@ -719,7 +709,7 @@
    #f
    'known-procedure/parameter))
 (define struct:known-procedure/parameter
-  (make-record-type-descriptor*
+  (make-record-type-descriptor
    'known-procedure/parameter
    (if (struct-type? struct:known-procedure/single-valued)
      struct:known-procedure/single-valued
@@ -735,8 +725,7 @@
     '())
    #f
    #f
-   0
-   0))
+   '(0 . 0)))
 (define effect_2451 (finish_2190 struct:known-procedure/parameter))
 (define known-procedure/parameter
   (|#%name|
@@ -775,7 +764,7 @@
    #f
    'known-procedure/can-inline))
 (define struct:known-procedure/can-inline
-  (make-record-type-descriptor*
+  (make-record-type-descriptor
    'known-procedure/can-inline
    (if (struct-type? struct:known-procedure)
      struct:known-procedure
@@ -791,8 +780,7 @@
     '(0))
    #f
    #f
-   1
-   1))
+   '(1 . 1)))
 (define effect_2308 (finish_2550 struct:known-procedure/can-inline))
 (define known-procedure/can-inline
   (|#%name|
@@ -848,7 +836,7 @@
    #f
    'known-procedure/can-inline/need-imports))
 (define struct:known-procedure/can-inline/need-imports
-  (make-record-type-descriptor*
+  (make-record-type-descriptor
    'known-procedure/can-inline/need-imports
    (if (struct-type? struct:known-procedure/can-inline)
      struct:known-procedure/can-inline
@@ -864,8 +852,7 @@
     '(0))
    #f
    #f
-   1
-   1))
+   '(1 . 1)))
 (define effect_2618
   (finish_1976 struct:known-procedure/can-inline/need-imports))
 (define known-procedure/can-inline/need-imports
@@ -922,7 +909,7 @@
    #f
    'known-procedure/folding))
 (define struct:known-procedure/folding
-  (make-record-type-descriptor*
+  (make-record-type-descriptor
    'known-procedure/folding
    (if (struct-type? struct:known-procedure/no-prompt)
      struct:known-procedure/no-prompt
@@ -938,8 +925,7 @@
     '())
    #f
    #f
-   0
-   0))
+   '(0 . 0)))
 (define effect_2478 (finish_1734 struct:known-procedure/folding))
 (define known-procedure/folding
   (|#%name|
@@ -978,7 +964,7 @@
    #f
    'known-procedure/folding/limited))
 (define struct:known-procedure/folding/limited
-  (make-record-type-descriptor*
+  (make-record-type-descriptor
    'known-procedure/folding/limited
    (if (struct-type? struct:known-procedure/folding)
      struct:known-procedure/folding
@@ -994,8 +980,7 @@
     '(0))
    #f
    #f
-   1
-   1))
+   '(1 . 1)))
 (define effect_2518 (finish_2008 struct:known-procedure/folding/limited))
 (define known-procedure/folding/limited
   (|#%name|
@@ -1051,7 +1036,7 @@
    #f
    'known-procedure/succeeds))
 (define struct:known-procedure/succeeds
-  (make-record-type-descriptor*
+  (make-record-type-descriptor
    'known-procedure/succeeds
    (if (struct-type? struct:known-procedure/no-prompt)
      struct:known-procedure/no-prompt
@@ -1067,8 +1052,7 @@
     '())
    #f
    #f
-   0
-   0))
+   '(0 . 0)))
 (define effect_2467 (finish_2826 struct:known-procedure/succeeds))
 (define known-procedure/succeeds
   (|#%name|
@@ -1107,7 +1091,7 @@
    #f
    'known-procedure/then-pure))
 (define struct:known-procedure/then-pure
-  (make-record-type-descriptor*
+  (make-record-type-descriptor
    'known-procedure/then-pure
    (if (struct-type? struct:known-procedure/succeeds)
      struct:known-procedure/succeeds
@@ -1123,8 +1107,7 @@
     '())
    #f
    #f
-   0
-   0))
+   '(0 . 0)))
 (define effect_1957 (finish_2544 struct:known-procedure/then-pure))
 (define known-procedure/then-pure
   (|#%name|
@@ -1163,7 +1146,7 @@
    #f
    'known-procedure/then-pure/folding-unsafe))
 (define struct:known-procedure/then-pure/folding-unsafe
-  (make-record-type-descriptor*
+  (make-record-type-descriptor
    'known-procedure/then-pure/folding-unsafe
    (if (struct-type? struct:known-procedure/then-pure)
      struct:known-procedure/then-pure
@@ -1179,8 +1162,7 @@
     '(0))
    #f
    #f
-   1
-   1))
+   '(1 . 1)))
 (define effect_2700
   (finish_2400 struct:known-procedure/then-pure/folding-unsafe))
 (define known-procedure/then-pure/folding-unsafe
@@ -1237,7 +1219,7 @@
    #f
    'known-procedure/allocates))
 (define struct:known-procedure/allocates
-  (make-record-type-descriptor*
+  (make-record-type-descriptor
    'known-procedure/allocates
    (if (struct-type? struct:known-procedure/succeeds)
      struct:known-procedure/succeeds
@@ -1253,8 +1235,7 @@
     '())
    #f
    #f
-   0
-   0))
+   '(0 . 0)))
 (define effect_2336 (finish_2051 struct:known-procedure/allocates))
 (define known-procedure/allocates
   (|#%name|
@@ -1293,7 +1274,7 @@
    #f
    'known-procedure/pure))
 (define struct:known-procedure/pure
-  (make-record-type-descriptor*
+  (make-record-type-descriptor
    'known-procedure/pure
    (if (struct-type? struct:known-procedure/allocates)
      struct:known-procedure/allocates
@@ -1309,8 +1290,7 @@
     '())
    #f
    #f
-   0
-   0))
+   '(0 . 0)))
 (define effect_3058 (finish_2724 struct:known-procedure/pure))
 (define known-procedure/pure
   (|#%name|
@@ -1346,7 +1326,7 @@
    #f
    'known-procedure/pure/folding))
 (define struct:known-procedure/pure/folding
-  (make-record-type-descriptor*
+  (make-record-type-descriptor
    'known-procedure/pure/folding
    (if (struct-type? struct:known-procedure/pure)
      struct:known-procedure/pure
@@ -1362,8 +1342,7 @@
     '())
    #f
    #f
-   0
-   0))
+   '(0 . 0)))
 (define effect_2264 (finish_2466 struct:known-procedure/pure/folding))
 (define known-procedure/pure/folding
   (|#%name|
@@ -1402,7 +1381,7 @@
    #f
    'known-procedure/has-unsafe))
 (define struct:known-procedure/has-unsafe
-  (make-record-type-descriptor*
+  (make-record-type-descriptor
    'known-procedure/has-unsafe
    (if (struct-type? struct:known-procedure/no-prompt)
      struct:known-procedure/no-prompt
@@ -1418,8 +1397,7 @@
     '(0))
    #f
    #f
-   1
-   1))
+   '(1 . 1)))
 (define effect_1752 (finish_3128 struct:known-procedure/has-unsafe))
 (define known-procedure/has-unsafe
   (|#%name|
@@ -1475,7 +1453,7 @@
    #f
    'known-procedure/has-unsafe/folding))
 (define struct:known-procedure/has-unsafe/folding
-  (make-record-type-descriptor*
+  (make-record-type-descriptor
    'known-procedure/has-unsafe/folding
    (if (struct-type? struct:known-procedure/has-unsafe)
      struct:known-procedure/has-unsafe
@@ -1491,8 +1469,7 @@
     '())
    #f
    #f
-   0
-   0))
+   '(0 . 0)))
 (define effect_2489 (finish_2439 struct:known-procedure/has-unsafe/folding))
 (define known-procedure/has-unsafe/folding
   (|#%name|
@@ -1531,7 +1508,7 @@
    #f
    'known-procedure/has-unsafe/folding/limited))
 (define struct:known-procedure/has-unsafe/folding/limited
-  (make-record-type-descriptor*
+  (make-record-type-descriptor
    'known-procedure/has-unsafe/folding/limited
    (if (struct-type? struct:known-procedure/has-unsafe/folding)
      struct:known-procedure/has-unsafe/folding
@@ -1547,8 +1524,7 @@
     '(0))
    #f
    #f
-   1
-   1))
+   '(1 . 1)))
 (define effect_2512
   (finish_2602 struct:known-procedure/has-unsafe/folding/limited))
 (define known-procedure/has-unsafe/folding/limited
@@ -1606,7 +1582,7 @@
    #f
    'known-struct-type))
 (define struct:known-struct-type
-  (make-record-type-descriptor*
+  (make-record-type-descriptor
    'known-struct-type
    (if (struct-type? struct:known-consistent)
      struct:known-consistent
@@ -1622,8 +1598,7 @@
     '(0 1 2 3))
    #f
    #f
-   4
-   15))
+   '(4 . 15)))
 (define effect_2667 (finish_2844 struct:known-struct-type))
 (define known-struct-type
   (|#%name|
@@ -1725,7 +1700,7 @@
    #f
    'known-constructor))
 (define struct:known-constructor
-  (make-record-type-descriptor*
+  (make-record-type-descriptor
    'known-constructor
    (if (struct-type? struct:known-procedure/allocates)
      struct:known-procedure/allocates
@@ -1741,8 +1716,7 @@
     '(0))
    #f
    #f
-   1
-   1))
+   '(1 . 1)))
 (define effect_1913 (finish_2453 struct:known-constructor))
 (define known-constructor
   (|#%name|
@@ -1793,7 +1767,7 @@
    #f
    'known-predicate))
 (define struct:known-predicate
-  (make-record-type-descriptor*
+  (make-record-type-descriptor
    'known-predicate
    (if (struct-type? struct:known-procedure/pure)
      struct:known-procedure/pure
@@ -1809,8 +1783,7 @@
     '(0))
    #f
    #f
-   1
-   1))
+   '(1 . 1)))
 (define effect_2144 (finish_2917 struct:known-predicate))
 (define known-predicate
   (|#%name|
@@ -1859,7 +1832,7 @@
    #f
    'known-accessor))
 (define struct:known-accessor
-  (make-record-type-descriptor*
+  (make-record-type-descriptor
    'known-accessor
    (if (struct-type? struct:known-procedure/single-valued)
      struct:known-procedure/single-valued
@@ -1875,8 +1848,7 @@
     '(0))
    #f
    #f
-   1
-   1))
+   '(1 . 1)))
 (define effect_2905 (finish_2548 struct:known-accessor))
 (define known-accessor
   (|#%name|
@@ -1925,7 +1897,7 @@
    #f
    'known-mutator))
 (define struct:known-mutator
-  (make-record-type-descriptor*
+  (make-record-type-descriptor
    'known-mutator
    (if (struct-type? struct:known-procedure/single-valued)
      struct:known-procedure/single-valued
@@ -1941,8 +1913,7 @@
     '(0))
    #f
    #f
-   1
-   1))
+   '(1 . 1)))
 (define effect_2521 (finish_2552 struct:known-mutator))
 (define known-mutator
   (|#%name|
@@ -1991,7 +1962,7 @@
    #f
    'known-struct-constructor))
 (define struct:known-struct-constructor
-  (make-record-type-descriptor*
+  (make-record-type-descriptor
    'known-struct-constructor
    (if (struct-type? struct:known-constructor)
      struct:known-constructor
@@ -2007,8 +1978,7 @@
     '(0))
    #f
    #f
-   1
-   1))
+   '(1 . 1)))
 (define effect_3238 (finish_2184 struct:known-struct-constructor))
 (define known-struct-constructor
   (|#%name|
@@ -2064,7 +2034,7 @@
    #f
    'known-struct-predicate))
 (define struct:known-struct-predicate
-  (make-record-type-descriptor*
+  (make-record-type-descriptor
    'known-struct-predicate
    (if (struct-type? struct:known-predicate)
      struct:known-predicate
@@ -2080,8 +2050,7 @@
     '(0 1 2))
    #f
    #f
-   3
-   7))
+   '(3 . 7)))
 (define effect_2384 (finish_2304 struct:known-struct-predicate))
 (define known-struct-predicate
   (|#%name|
@@ -2168,7 +2137,7 @@
    #f
    'known-field-accessor))
 (define struct:known-field-accessor
-  (make-record-type-descriptor*
+  (make-record-type-descriptor
    'known-field-accessor
    (if (struct-type? struct:known-accessor)
      struct:known-accessor
@@ -2184,8 +2153,7 @@
     '(0 1 2 3))
    #f
    #f
-   4
-   15))
+   '(4 . 15)))
 (define effect_2259 (finish_3014 struct:known-field-accessor))
 (define known-field-accessor
   (|#%name|
@@ -2289,7 +2257,7 @@
    #f
    'known-field-mutator))
 (define struct:known-field-mutator
-  (make-record-type-descriptor*
+  (make-record-type-descriptor
    'known-field-mutator
    (if (struct-type? struct:known-mutator)
      struct:known-mutator
@@ -2305,8 +2273,7 @@
     '(0 1 2))
    #f
    #f
-   3
-   7))
+   '(3 . 7)))
 (define effect_2603 (finish_2908 struct:known-field-mutator))
 (define known-field-mutator
   (|#%name|
@@ -2393,7 +2360,7 @@
    #f
    'known-struct-constructor/need-imports))
 (define struct:known-struct-constructor/need-imports
-  (make-record-type-descriptor*
+  (make-record-type-descriptor
    'known-struct-constructor/need-imports
    (if (struct-type? struct:known-struct-constructor)
      struct:known-struct-constructor
@@ -2409,8 +2376,7 @@
     '(0))
    #f
    #f
-   1
-   1))
+   '(1 . 1)))
 (define effect_2146 (finish_2543 struct:known-struct-constructor/need-imports))
 (define known-struct-constructor/need-imports
   (|#%name|
@@ -2466,7 +2432,7 @@
    #f
    'known-struct-predicate/need-imports))
 (define struct:known-struct-predicate/need-imports
-  (make-record-type-descriptor*
+  (make-record-type-descriptor
    'known-struct-predicate/need-imports
    (if (struct-type? struct:known-struct-predicate)
      struct:known-struct-predicate
@@ -2482,8 +2448,7 @@
     '(0))
    #f
    #f
-   1
-   1))
+   '(1 . 1)))
 (define effect_3156 (finish_2626 struct:known-struct-predicate/need-imports))
 (define known-struct-predicate/need-imports
   (|#%name|
@@ -2539,7 +2504,7 @@
    #f
    'known-field-accessor/need-imports))
 (define struct:known-field-accessor/need-imports
-  (make-record-type-descriptor*
+  (make-record-type-descriptor
    'known-field-accessor/need-imports
    (if (struct-type? struct:known-field-accessor)
      struct:known-field-accessor
@@ -2555,8 +2520,7 @@
     '(0))
    #f
    #f
-   1
-   1))
+   '(1 . 1)))
 (define effect_2513 (finish_2444 struct:known-field-accessor/need-imports))
 (define known-field-accessor/need-imports
   (|#%name|
@@ -2612,7 +2576,7 @@
    #f
    'known-field-mutator/need-imports))
 (define struct:known-field-mutator/need-imports
-  (make-record-type-descriptor*
+  (make-record-type-descriptor
    'known-field-mutator/need-imports
    (if (struct-type? struct:known-field-mutator)
      struct:known-field-mutator
@@ -2628,8 +2592,7 @@
     '(0))
    #f
    #f
-   1
-   1))
+   '(1 . 1)))
 (define effect_2273 (finish_2153 struct:known-field-mutator/need-imports))
 (define known-field-mutator/need-imports
   (|#%name|
@@ -2683,7 +2646,7 @@
    #f
    'known-struct-type-property/immediate-guard))
 (define struct:known-struct-type-property/immediate-guard
-  (make-record-type-descriptor*
+  (make-record-type-descriptor
    'known-struct-type-property/immediate-guard
    #f
    (structure-type-lookup-prefab-uid
@@ -2695,8 +2658,7 @@
     '())
    #f
    #f
-   0
-   0))
+   '(0 . 0)))
 (define effect_2294
   (finish_2492 struct:known-struct-type-property/immediate-guard))
 (define known-struct-type-property/immediate-guard
