@@ -16,11 +16,13 @@
 #endif
 
 #ifdef RKTIO_SYSTEM_UNIX
-static rktio_fd_t *finish_unix_fd_creation(rktio_t *rktio, int fd, int modes, rktio_fd_t *existing_rfd);
+static rktio_fd_t *finish_unix_fd_creation(rktio_t *rktio, int fd, int modes, rktio_fd_t *existing_rfd,
+                                           int perm_bits, int replace_perms);
 #endif
 
 #ifdef RKTIO_USE_PENDING_OPEN
-static rktio_fd_t *open_via_thread(rktio_t *rktio, const char *filename, int modes, int flags, int perm_bits);
+static rktio_fd_t *open_via_thread(rktio_t *rktio, const char *filename, int modes, int flags,
+                                   int perm_bits, int replace_perms);
 static int do_pending_open_release(rktio_t *rktio, struct open_in_thread_t *data, int close_fd);
 #endif
 
@@ -136,7 +138,8 @@ static rktio_fd_t *open_write(rktio_t *rktio, const char *filename, int modes, i
   if (errno == ENXIO) {
     /* FIFO with no reader? */
 #ifdef RKTIO_USE_PENDING_OPEN
-    return open_via_thread(rktio, filename, modes, flags | RKTIO_BINARY, perm_bits);
+    return open_via_thread(rktio, filename, modes, flags | RKTIO_BINARY,
+                           perm_bits, modes & RKTIO_OPEN_REPLACE_PERMS);
 #else
     /* Try opening in RW mode: */
     flags -= O_WRONLY;
@@ -147,7 +150,7 @@ static rktio_fd_t *open_write(rktio_t *rktio, const char *filename, int modes, i
 #endif
   }
 
-  return finish_unix_fd_creation(rktio, fd, modes, NULL);
+  return finish_unix_fd_creation(rktio, fd, modes, NULL, perm_bits, modes & RKTIO_OPEN_REPLACE_PERMS);
 #endif
 #ifdef RKTIO_SYSTEM_WINDOWS
   HANDLE fd;
@@ -193,6 +196,28 @@ static rktio_fd_t *open_write(rktio_t *rktio, const char *filename, int modes, i
     }
   }
 
+  if (modes & RKTIO_OPEN_REPLACE_PERMS) {
+    FILE_BASIC_INFO info;
+    if (GetFileInformationByHandleEx(fd, FileBasicInfo, &info, sizeof(info))) {
+      DWORD attr = ((perm_bits & RKTIO_PERMISSION_WRITE) ? 0 : FILE_ATTRIBUTE_READONLY);
+      if ((info.FileAttributes & FILE_ATTRIBUTE_READONLY) != attr) {
+        if (attr)
+          info.FileAttributes |= attr;
+        else
+          info.FileAttributes -= attr;
+        if (!SetFileInformationByHandle(fd, FileBasicInfo, &info, sizeof(info))) {
+          get_windows_error();
+          CloseHandle(fd);
+          return NULL;
+        }
+      }
+    } else {
+      get_windows_error();
+      CloseHandle(fd);
+      return NULL;
+    }
+  }
+
   rfd = rktio_system_fd(rktio, (intptr_t)fd, modes);
 
   if (rktio_fd_is_directory(rktio, rfd)) {
@@ -222,7 +247,8 @@ static rktio_fd_t *open_write(rktio_t *rktio, const char *filename, int modes, i
 }
 
 #ifdef RKTIO_SYSTEM_UNIX
-static rktio_fd_t *finish_unix_fd_creation(rktio_t *rktio, int fd, int modes, rktio_fd_t *existing_rfd)
+static rktio_fd_t *finish_unix_fd_creation(rktio_t *rktio, int fd, int modes, rktio_fd_t *existing_rfd,
+                                           int perm_bits, int replace_perms)
 {
   struct stat buf;
   int cr;
@@ -245,6 +271,19 @@ static rktio_fd_t *finish_unix_fd_creation(rktio_t *rktio, int fd, int modes, rk
     }
   }
 
+  if (replace_perms) {
+    do {
+      cr = fchmod(fd, perm_bits);
+    } while ((cr == -1) && (errno == EINTR));
+    if (cr == -1) {
+      get_posix_error();
+      do {
+        cr = close(fd);
+      } while ((cr == -1) && (errno == EINTR));
+      return NULL;
+    }
+  }
+
   do {
     cr = fstat(fd, &buf);
   } while ((cr == -1) && (errno == EINTR));
@@ -444,6 +483,7 @@ typedef struct open_in_thread_t {
   char *filename;
   int flags;
   int perm_bits;
+  int replace_perms;
   int done;
   int fd;
   int errval;
@@ -528,7 +568,8 @@ static void *do_open_in_thread(void *_data)
   return NULL;
 }
 
-static rktio_fd_t *open_via_thread(rktio_t *rktio, const char *filename, int modes, int flags, int perm_bits)
+static rktio_fd_t *open_via_thread(rktio_t *rktio, const char *filename, int modes, int flags,
+                                   int perm_bits, int replace_perms)
 {
   open_in_thread_t *data;
 
@@ -539,6 +580,7 @@ static rktio_fd_t *open_via_thread(rktio_t *rktio, const char *filename, int mod
   data->filename = strdup(filename);
   data->flags = flags;
   data->perm_bits = perm_bits;
+  data->replace_perms = replace_perms;
   pthread_mutex_init(&data->lock, NULL);
   pthread_cond_init(&data->ready_cond, NULL);
 
@@ -570,8 +612,10 @@ int rktio_pending_open_poll(rktio_t *rktio, rktio_fd_t *existing_rfd, struct ope
       return data->errval;
     else {
       int fd = data->fd;
+      int perm_bits = data->perm_bits;
+      int replace_perms = data->replace_perms;
       (void)do_pending_open_release(rktio, data, 0);
-      if (!finish_unix_fd_creation(rktio, fd, 0, existing_rfd)) {
+      if (!finish_unix_fd_creation(rktio, fd, 0, existing_rfd, perm_bits, replace_perms)) {
         /* Posix error must be saved in `rktio` */
         return rktio->errid;
       }
