@@ -55,9 +55,13 @@
 #endif
 
 #ifdef _WIN64
-#define HOST_MACHINE IMAGE_FILE_MACHINE_AMD64
+# if defined(_M_ARM64)
+#  define HOST_MACHINE IMAGE_FILE_MACHINE_ARM64
+# else
+#  define HOST_MACHINE IMAGE_FILE_MACHINE_AMD64
+# endif
 #else
-#define HOST_MACHINE IMAGE_FILE_MACHINE_I386
+# define HOST_MACHINE IMAGE_FILE_MACHINE_I386
 #endif
 
 #include "MemoryModule.h"
